==> ckeditor5_premium_features-1.1.0.tar.gz: ckeditor5_premium_features/README.md <==
# CKEditor 5 Premium Features

CKEditor 5 Premium features are a module for Drupal 9/10 that will provide a set of collaborative solutions and the ability to export your content to popular portable and cross-platform formats.

At the moment the CKEditor 5 Premium features offer:

 * Real-time collaboration - **optional**, you may use Track changes and Comments without Real-time collaboration too (!)
 * Track changes
 * Comments
 * Revision history - a more sophisticated history of changes inside the document
 * Notifications - configurable notifications to stay up to date whenever someone mentions you in a document, comment, accepts/rejects suggestions, replies to your comment and so on. You may use your own plugin for notifications to get e.g. notifications on slack.

It also provides the following file formats converters:

 * Export to Word - marked as experimental (works but requires manual corrections to CSS for the best experience) 
 * Export to PDF - marked as experimental (works but requires manual corrections to CSS for the best experience)

For a full description of the module, visit the
[project page](https://www.drupal.org/project/ckeditor5_premium_features).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/ckeditor5_premium_features).


## CKEditor 5 Premium Features Module

The CKEditor 5 Premium Features module: [project page](https://www.drupal.org/project/ckeditor5_premium_features)

Online documentation: [CKEditor 5 Premium Features](https://www.drupal.org/docs/contributed-modules/ckeditor-5-premium-features)


## Status 🚧

The module is currently under development. You are free to try it out and experiment. Have questions about the status, roadmap or would you like to use it in your project? Contact us: [ckeditor](https://ckeditor.com/contact/)

Reporting issues: [issue queue](https://www.drupal.org/project/issues/ckeditor5_premium_features)


## Installation:

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

### Using composer:
```composer require drupal/ckeditor5_premium_features```


## Requirements

**PHP** >= 8.1

**Drupal** >= 9.4 || 10


## Configuration

Online documentation: [CKEditor 5 Premium Features](https://www.drupal.org/docs/contributed-modules/ckeditor-5-premium-features)


## Free trial

In order to use the module, you will need to sign up to the free trial of CKEditor 5 premium features: [CKEditor features](https://orders.ckeditor.com/trial/premium-features) and configure the module later.


## Uninstallation

### Using composer:
```composer require remove/ckeditor5_premium_features```


## License

Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.

Licensed under the terms of GNU General Public License Version 2 or later.

==> ckeditor5_premium_features-1.2.4.tar.gz: ckeditor5_premium_features/README.md <==
# CKEditor 5 Premium Features

CKEditor 5 Premium features are a module for Drupal 9/10 that will provide a set of collaborative solutions and the ability to export your content to popular portable and cross-platform formats.

At the moment the CKEditor 5 Premium features offer:

 * Real-time collaboration - **optional**, you may use Track changes and Comments without Real-time collaboration too (!)
 * Track changes
 * Comments
 * Revision history - a more sophisticated history of changes inside the document
 * Notifications - configurable notifications to stay up to date whenever someone mentions you in a document, comment, accepts/rejects suggestions, replies to your comment and so on. You may use your own plugin for notifications to get e.g. notifications on slack.
 * Productivity pack - a set of exclusive premium features, that make editing faster, easier, and more efficient.
 * Full screen mode - a free-to-use plugin that allows maximising the editing area.

It also provides the following file formats converters:

 * Export to Word - marked as experimental (works but requires manual corrections to CSS for the best experience).
 * Export to PDF - marked as experimental (works but requires manual corrections to CSS for the best experience).

For a full description of the module, visit the
[project page](https://www.drupal.org/project/ckeditor5_premium_features).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/ckeditor5_premium_features).


## CKEditor 5 Premium Features Module

The CKEditor 5 Premium Features module: [project page](https://www.drupal.org/project/ckeditor5_premium_features)

Online documentation: [CKEditor 5 Premium Features](https://www.drupal.org/docs/contributed-modules/ckeditor-5-premium-features)


## Status

The module is actively maintained. Having questions about the status, roadmap or would you like to use it in your project? Contact us: [ckeditor](https://ckeditor.com/contact/)

Reporting issues: [issue queue](https://www.drupal.org/project/issues/ckeditor5_premium_features)


## Installation:

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

### Using composer:

```composer require drupal/ckeditor5_premium_features```


## Requirements

**PHP** >= 8.1

**Drupal** >= 9.4 || 10


## Configuration

Online documentation: [CKEditor 5 Premium Features](https://www.drupal.org/docs/contributed-modules/ckeditor-5-premium-features)


## Free trial

In order to use the module, you will need to sign up to the free trial of CKEditor 5 premium features: [CKEditor features](https://orders.ckeditor.com/trial/premium-features) and configure the module later.


## Uninstallation

Uninstall all submodules and the main CKEditor 5 Premium Features module in the administrative GUI: /admin/modules/uninstall

### Using composer:

To remove the module files after uninstallation, run
```composer remove drupal/ckeditor5_premium_features```


## License

Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.

Licensed under the terms of GNU General Public License Version 2 or later.
